Ketos is a software package for acoustic data analysis with neural networks. 
It was developed with a particular eye to detection and classification tasks in underwater acoustics.
Ketos is written in Python and utilizes a number of powerful software packages 
including NumPy, HDF5, and Tensorflow.
It is licensed under the [GNU GPLv3 licens](https://www.gnu.org/licenses/) and hence freely available for anyone to use and modify.
The project is hosted on GitLab at 
[gitlab.meridian.cs.dal.ca/public_projects/ketos](https://gitlab.meridian.cs.dal.ca/public_projects/ketos).

You can install the latest version of Ketos from the Python Package Index (PyPI) repository with
```terminal
pip install ketos
```
For more information, please consult [Ketos' Documentation Page](https://docs.meridian.cs.dal.ca/ketos/).

Ketos was developed by the [MERIDIAN](http://meridian.cs.dal.ca/) Data Analytics Team at the 
[Institute for Big Data Analytics](https://bigdata.cs.dal.ca/) at Dalhousie University. 
We are greatful to Amalis Riera and Francis Juanes at the University of Victoria, 
Kim Davies and Chris Taggart at Dalhousie University, and Kristen Kanes at Ocean Networks Canada 
for providing us with annotated acoustic data sets, which played a key role in the development work.
The first version of Ketos was released in April 2019. 

The intended users of Ketos are primarily researchers and data scientists working with (underwater) acoustics data. 
While Ketos comes with complete documentation and comprehensive step-by-step tutorials, some familiarity with Python and especially the NumPy package would be beneficial. A basic understanding of 
the fundamentals of machine learning and neural networks would also be an advantage.

The name Ketos was chosen to highlight the package's main intended application, underwater acoustics.
In Ancient Greek, the word ketos denotes a large fish, whale, shark, or sea monster. The word ketos 
is also the origin of the scientific term for whales, cetacean.